==> Pyrogram-0.6.4-py3-none-any.whl: pyrogram/api/functions/langpack/get_lang_pack.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class GetLangPack(Object):
    """
    Attributes:
        ID (:obj:`int`): ``0x9ab5c58e``

    Args:
        lang_code: :obj:`string`

    Returns:
        :class:`pyrogram.api.types.LangPackDifference`

    Raises:
        :class:`pyrogram.Error`
    """
    ID = 0x9ab5c58e

    def __init__(self, lang_code):
        self.lang_code = lang_code  # string

    @staticmethod
    def read(b: BytesIO, *args) -> "GetLangPack":
        # No flags
        
        lang_code = String.read(b)
        
        return GetLangPack(lang_code)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.lang_code))
        
        return b.getvalue()

==> Pyrogram-0.7.1-py3-none-any.whl: pyrogram/api/functions/langpack/get_lang_pack.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class GetLangPack(Object):
    """Attributes:
        ID: ``0x9ab5c58e``

    Args:
        lang_code: ``str``

    Raises:
        :obj:`Error <pyrogram.Error>`

    Returns:
        :obj:`LangPackDifference <pyrogram.api.types.LangPackDifference>`
    """
    ID = 0x9ab5c58e

    def __init__(self, lang_code):
        self.lang_code = lang_code  # string

    @staticmethod
    def read(b: BytesIO, *args) -> "GetLangPack":
        # No flags
        
        lang_code = String.read(b)
        
        return GetLangPack(lang_code)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.lang_code))
        
        return b.getvalue()
